@@ -9,14 +9,14 @@ from rich.console import RenderableType
 
 from textual import _widget_navigation
 from textual.binding import Binding, BindingType
-from textual.containers import Container
+from textual.containers import VerticalScroll
 from textual.events import Click, Mount
 from textual.message import Message
-from textual.reactive import var
+from textual.reactive import reactive, var
 from textual.widgets._radio_button import RadioButton
 
 
-class RadioSet(Container, can_focus=True, can_focus_children=False):
+class RadioSet(VerticalScroll, can_focus=True, can_focus_children=False):
     """Widget for grouping a collection of radio buttons into a set.
 
     When a collection of [`RadioButton`][textual.widgets.RadioButton]s are
@@ -25,39 +25,55 @@ class RadioSet(Container, can_focus=True, can_focus_children=False):
     turned off.
     """
 
+    ALLOW_SELECT = False
+    ALLOW_MAXIMIZE = True
+
     DEFAULT_CSS = """
     RadioSet {
-        border: tall transparent;
-        background: $boost;
-        padding: 0 1 0 0;
+        border: tall $border-blurred;
+        background: $surface;
+        padding: 0 1;        
         height: auto;
-        width: auto;
-    }
+        width: 1fr;
 
-    RadioSet:focus {
-        border: tall $accent;
-    }
+        &.-textual-compact {
+            border: none !important;
+            padding: 0;
+        }
 
-    /* The following rules/styles mimic similar ToggleButton:focus rules in
-     * ToggleButton. If those styles ever get updated, these should be too.
-     */
+        & > RadioButton {
+            background: transparent;
+            border: none;
+            padding: 0;
+            width: 1fr;
 
-    RadioSet > * {
-        background: transparent;
-        border: none;
-        padding: 0 1;
-    }
+            & > .toggle--button {
+                color: $panel-darken-2;
+                background: $panel;
+            }
 
-    RadioSet:focus > RadioButton.-selected > .toggle--label {
-        text-style: underline;
-    }
+            &.-selected {
+                background: $block-cursor-blurred-background;
+            }
+        }
 
-    RadioSet:focus ToggleButton.-selected > .toggle--button {
-        background: $foreground 25%;
-    }
+        & > RadioButton.-on .toggle--button {
+            color: $text-success;
+        }
 
-    RadioSet:focus > RadioButton.-on.-selected > .toggle--button {
-        background: $foreground 25%;
+        &:focus {
+            /* The following rules/styles mimic similar ToggleButton:focus rules in
+            * ToggleButton. If those styles ever get updated, these should be too.
+            */
+            border: tall $border;
+            background-tint: $foreground 5%;
+            & > RadioButton.-selected {
+                color: $block-cursor-foreground;
+                text-style: $block-cursor-text-style;
+                background: $block-cursor-background;
+            }
+
+        }
     }
     """
 
@@ -77,6 +93,9 @@ class RadioSet(Container, can_focus=True, can_focus_children=False):
     _selected: var[int | None] = var[Optional[int]](None)
     """The index of the currently-selected radio button."""
 
+    compact: reactive[bool] = reactive(False, toggle_class="-textual-compact")
+    """Enable compact display?"""
+
     @rich.repr.auto
     class Changed(Message):
         """Posted when the pressed button in the set changes.
@@ -123,6 +142,7 @@ class RadioSet(Container, can_focus=True, can_focus_children=False):
         classes: str | None = None,
         disabled: bool = False,
         tooltip: RenderableType | None = None,
+        compact: bool = False,
     ) -> None:
         """Initialise the radio set.
 
@@ -133,6 +153,7 @@ class RadioSet(Container, can_focus=True, can_focus_children=False):
             classes: The CSS classes of the radio set.
             disabled: Whether the radio set is disabled or not.
             tooltip: Optional tooltip.
+            compact: Enable compact radio set style
 
         Note:
             When a `str` label is provided, a
@@ -153,6 +174,7 @@ class RadioSet(Container, can_focus=True, can_focus_children=False):
         )
         if tooltip is not None:
             self.tooltip = tooltip
+        self.compact = compact
 
     def _on_mount(self, _: Mount) -> None:
         """Perform some processing once mounted in the DOM."""
@@ -188,6 +210,7 @@ class RadioSet(Container, can_focus=True, can_focus_children=False):
         self.query(RadioButton).remove_class("-selected")
         if self._selected is not None:
             self._nodes[self._selected].add_class("-selected")
+            self._scroll_to_selected()
 
     def _on_radio_button_changed(self, event: RadioButton.Changed) -> None:
         """Respond to the value of a button in the set being changed.
@@ -276,3 +299,9 @@ class RadioSet(Container, can_focus=True, can_focus_children=False):
             button = self._nodes[self._selected]
             assert isinstance(button, RadioButton)
             button.toggle()
+
+    def _scroll_to_selected(self) -> None:
+        """Ensure that the selected button is in view."""
+        if self._selected is not None:
+            button = self._nodes[self._selected]
+            self.call_after_refresh(self.scroll_to_widget, button, animate=False)
